==> Map-Tube-Sydney-1.0.0.tar.gz: Map-Tube-Sydney-1.0.0/lib/Map/Tube/Sydney/Line/M1.pm <==
package Map::Tube::Sydney::Line::M1;

$Map::Tube::Sydney::Line::Central::VERSION   = '1.00';
$Map::Tube::Sydney::Line::Central::AUTHORITY = 'cpan:EARLYBEAN';

use 5.006;
use strict; use warnings;

=head1 NAME

Map::Tube::Sydney::Line::M1 - Sydney Rail Map: Sydney M1 Line.

=head1 VERSION

Version 1.00

=encoding utf8

=head1 DESCRIPTION

Sydney Rail Map: Sydney M1 Line.

    +----------------------+-----------------------------------+
    | Station Name         | Linked To                         |
    +----------------------+-----------------------------------+
    | Tallawong            | Rouse Hill                        |
    | Rouse Hill           | Tallawong, Kellyville             |
    | Kellyville           | Rouse Hill, Bella Vista           |
    | Bella Vista          | Kellyville, Norwest               |
    | Norwest              | Bella Vista, Hills Showground     |
    | Hills Showground     | Norwest, Castle Hill              |
    | Castle Hill          | Hills Showground, Cherrybrook     |
    | Cherrybrook          | Castle Hill, Epping               |
    | Epping               | Cherrybrook, Macquarie University |
    | Macquarie University | Epping, Macquarie Park            |
    | Macquarie Park       | Macquarie University, North Ryde  |
    | North Ryde           | Macquarie Park, Chatswood         |
    | Chatswood            | North Ryde, Crows Nest            |
    | Crows Nest           | Chatswood, Victoria Cross         |
    | Victoria Cross       | Crows Nest, Barangaroo            |
    | Barangaroo           | Victoria Cross, Martin Place      |
    | Martin Place         | Barangaroo, Gadigal               |
    | Gadigal              | Martin Place, Central             |
    | Central              | Gadigal, Waterloo                 |
    | Waterloo             | Central, Sydenham                 |
    | Sydenham             | Waterloo                          |
    +----------------------+-----------------------------------+

=head1 NOTE

=over 2

=item * The station "Central" is also part of
          L<T1 Line|Map::Tube::Sydney::Line::T1>
        | L<T2 Line|Map::Tube::Sydney::Line::T2>
        | L<T3 Line|Map::Tube::Sydney::Line::T3>
        | L<T4 Line|Map::Tube::Sydney::Line::T4>
        | L<T8 Line|Map::Tube::Sydney::Line::T8>
        | L<T9 Line|Map::Tube::Sydney::Line::T9>

=item * The station "Chatswood" is also part of
          L<T1 Line|Map::Tube::Sydney::Line::T1>
        | L<T9 Line|Map::Tube::Sydney::Line::T9>

=item * The station "Epping" is also part of
          L<T9 Line|Map::Tube::Sydney::Line::T9>

=item * The station "Martin Place" is also part of
          L<T4 Line|Map::Tube::Sydney::Line::T4>

=item * The station "Sydenham" is also part of
          L<T4 Line|Map::Tube::Sydney::Line::T4>
        | L<T8 Line|Map::Tube::Sydney::Line::T8>

=item * The line is currently being extended from Sydenham to Bankstown, with the planned opening due in 2026.

=back

=head1 MAP

Sydney Rail Map: L<Sydney M1 Line|https://raw.githubusercontent.com/earlybean4/Map-Tube-Sydney/master/maps/M1.png>
map generated by plugin L<Map::Tube::Plugin::Graph>.

=begin html

<a href = "https://raw.githubusercontent.com/earlybean4/Map-Tube-Sydney/master/maps/M1.png">
<img src    = "https://raw.githubusercontent.com/earlybean4/Map-Tube-Sydney/master/maps/M1.png"
     alt    = "Sydney Rail Map: Sydney M1 Line"
     width  = "800px"
     height = "830px"/>
</a>

=end html

=head1 AUTHOR

Peter Harrison, C<< <pete at 28smith.com> >>

=head1 REPOSITORY

L<https://github.com/earlybean4/Map-Tube-Sydney>

=head1 BUGS

Please report any bugs or feature requests through the web interface at L<https://github.com/earlybean4/Map-Tube-Sydney/issues>.
I will  be notified and then you'll automatically be notified of progress on your
bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Map::Tube::Sydney::Line::M1

You can also look for information at:

=over 4

=item * BUG Report

L<https://github.com/earlybean4/Map-Tube-Sydney/issues>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Map-Tube-Sydney>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Map-Tube-Sydney>

=item * Search MetaCPAN

L<https://metacpan.org/dist/Map-Tube-Sydney>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2025 Peter Harrison.

This program is  free software;  you can redistribute it and / or modify it under
the  terms  of the the Artistic License (2.0). You may obtain a  copy of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Map::Tube::Sydney::Line::M1

==> Map-Tube-Sydney-1.0.1.tar.gz: Map-Tube-Sydney-1.0.1/lib/Map/Tube/Sydney/Line/M1.pm <==
package Map::Tube::Sydney::Line::M1;

$Map::Tube::Sydney::Line::Central::VERSION   = '1.01';
$Map::Tube::Sydney::Line::Central::AUTHORITY = 'cpan:EARLYBEAN';

use 5.006;
use strict; use warnings;

=head1 NAME

Map::Tube::Sydney::Line::M1 - Sydney Rail Map: M1 Line.

=head1 VERSION

Version 1.01

=encoding utf8

=head1 DESCRIPTION

Sydney Rail Map: Sydney M1 Line.

    +----------------------+-----------------------------------+
    | Station Name         | Linked To                         |
    +----------------------+-----------------------------------+
    | Tallawong            | Rouse Hill                        |
    | Rouse Hill           | Tallawong, Kellyville             |
    | Kellyville           | Rouse Hill, Bella Vista           |
    | Bella Vista          | Kellyville, Norwest               |
    | Norwest              | Bella Vista, Hills Showground     |
    | Hills Showground     | Norwest, Castle Hill              |
    | Castle Hill          | Hills Showground, Cherrybrook     |
    | Cherrybrook          | Castle Hill, Epping               |
    | Epping               | Cherrybrook, Macquarie University |
    | Macquarie University | Epping, Macquarie Park            |
    | Macquarie Park       | Macquarie University, North Ryde  |
    | North Ryde           | Macquarie Park, Chatswood         |
    | Chatswood            | North Ryde, Crows Nest            |
    | Crows Nest           | Chatswood, Victoria Cross         |
    | Victoria Cross       | Crows Nest, Barangaroo            |
    | Barangaroo           | Victoria Cross, Martin Place      |
    | Martin Place         | Barangaroo, Gadigal               |
    | Gadigal              | Martin Place, Central             |
    | Central              | Gadigal, Waterloo                 |
    | Waterloo             | Central, Sydenham                 |
    | Sydenham             | Waterloo                          |
    +----------------------+-----------------------------------+

=head1 NOTE

=over 2

=item * The station "Central" is also part of
          L<T1 Line|Map::Tube::Sydney::Line::T1>
        | L<T2 Line|Map::Tube::Sydney::Line::T2>
        | L<T3 Line|Map::Tube::Sydney::Line::T3>
        | L<T4 Line|Map::Tube::Sydney::Line::T4>
        | L<T8 Line|Map::Tube::Sydney::Line::T8>
        | L<T9 Line|Map::Tube::Sydney::Line::T9>

=item * The station "Chatswood" is also part of
          L<T1 Line|Map::Tube::Sydney::Line::T1>
        | L<T9 Line|Map::Tube::Sydney::Line::T9>

=item * The station "Epping" is also part of
          L<T9 Line|Map::Tube::Sydney::Line::T9>

=item * The station "Martin Place" is also part of
          L<T4 Line|Map::Tube::Sydney::Line::T4>

=item * The station "Sydenham" is also part of
          L<T4 Line|Map::Tube::Sydney::Line::T4>
        | L<T8 Line|Map::Tube::Sydney::Line::T8>

=item * The line is currently being extended from Sydenham to Bankstown, with the planned opening due in 2026.

=back

=head1 MAP

Sydney Rail Map: L<Sydney M1 Line|https://raw.githubusercontent.com/earlybean4/Map-Tube-Sydney/master/maps/M1.png>
map generated by plugin L<Map::Tube::Plugin::Graph>.

=begin html

<a href = "https://raw.githubusercontent.com/earlybean4/Map-Tube-Sydney/master/maps/M1.png">
<img src    = "https://raw.githubusercontent.com/earlybean4/Map-Tube-Sydney/master/maps/M1.png"
     alt    = "Sydney Rail Map: Sydney M1 Line"
     width  = "800px"
     height = "830px"/>
</a>

=end html

=head1 AUTHOR

Peter Harrison, C<< <pete at 28smith.com> >>

=head1 REPOSITORY

L<https://github.com/earlybean4/Map-Tube-Sydney>

=head1 BUGS

Please report any bugs or feature requests through the web interface at L<https://github.com/earlybean4/Map-Tube-Sydney/issues>.
I will  be notified and then you'll automatically be notified of progress on your
bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Map::Tube::Sydney::Line::M1

You can also look for information at:

=over 4

=item * BUG Report

L<https://github.com/earlybean4/Map-Tube-Sydney/issues>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Map-Tube-Sydney>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Map-Tube-Sydney>

=item * Search MetaCPAN

L<https://metacpan.org/dist/Map-Tube-Sydney>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2025 Peter Harrison.

This program is  free software;  you can redistribute it and / or modify it under
the  terms  of the the Artistic License (2.0). You may obtain a  copy of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Map::Tube::Sydney::Line::M1
